indicatortools.Clef
===================

.. abjad-lineage:: abjad.tools.indicatortools.Clef.Clef

.. autoclass:: abjad.tools.indicatortools.Clef.Clef

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.Clef.Clef.middle_c_position
      ~abjad.tools.indicatortools.Clef.Clef.name
      ~abjad.tools.indicatortools.Clef.Clef.__copy__
      ~abjad.tools.indicatortools.Clef.Clef.__eq__
      ~abjad.tools.indicatortools.Clef.Clef.__format__
      ~abjad.tools.indicatortools.Clef.Clef.__hash__
      ~abjad.tools.indicatortools.Clef.Clef.__ne__
      ~abjad.tools.indicatortools.Clef.Clef.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.Clef.Clef.middle_c_position
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.Clef.Clef.name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.Clef.Clef.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Clef.Clef.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Clef.Clef.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Clef.Clef.__hash__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Clef.Clef.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Clef.Clef.__repr__
   :noindex:
